==> rec10%200.9.0.tar.bz2: rec10 0.9.0/rec10/gridserver.py <==
#!/usr/bin/python
# coding: UTF-8
# Rec10 TS Recording Tools
# Copyright (C) 2009 Yukikaze
from SocketServer import *

import configreader
import recdb
import recdblist
RECV_BUF = 8192

class Handler(BaseRequestHandler):
    """
    This is a server to encode ts files in another pc.

    """
    def handle(self):
        recdblist.printutf8("connect from:", self.client_address)
        cons = getTask()
        recdblist.printutf8(cons + " is sent")
        self.request.send(cons)
        """while True:
            #ret = self.request.recv(RECV_BUF)
            #if len(ret) == 0:
            #    break
            self.request.send()

            """
        self.request.close()

def getTask():
    tasks = recdb.getnow("1")
    rett = ""
    for task in tasks:
        if task["type"] == recdblist.REC_ENCODE_QUE:
            title = task['title']
            opt = task['opt']
            btime = task['btime']
            etime = task['etime']
            chtxt = task['chtxt']
            recdb.del_reckey(recdblist.REC_ENCODE_QUE, title, chtxt, btime)
            recdb.rec_reckey(recdblist.REC_ENCODE_GRID, title, chtxt, btime, etime, opt)
            rett = "title=" + title + "," + "opt=" + opt + ";"
            break
    return rett
def main():
    port = int(configreader.getpath("gridserver_port"))
    sv = ThreadingTCPServer(('', port), Handler)
    recdblist.printutf8("This is a Rec10 GridServer.")
    recdblist.printutf8("Waiting for connections at port" + str(port))
    recdblist.printutf8('listen to:', sv.socket.getsockname())
    sv.serve_forever()

if __name__ == '__main__': main()

==> rec10%200.9.6.tar.bz2: rec10 0.9.6/rec10/gridserver.py <==
#!/usr/bin/python
# coding: UTF-8
# Rec10 TS Recording Tools
# Copyright (C) 2009-2010 Yukikaze
from SocketServer import *

import configreader
import re
import recdb
import recdblist
RECV_BUF = 8192

class Handler(BaseRequestHandler):
    """
    This is a server to encode ts files in another pc.

    """
    def handle(self):
        print("connect from:", self.client_address)
        cons = getTask()
        recdblist.printutf8(cons + " is sent")
        self.request.send(cons.encode('UTF-8'))
        """while True:
            #ret = self.request.recv(RECV_BUF)
            #if len(ret) == 0:
            #    break
            self.request.send()

            """
        self.request.close()

def getTask():
    tasks = recdb.getnow("1")
    rett = ""
    for task in tasks:
        if task["type"] == recdblist.REC_ENCODE_QUE and not re.search("d",task['opt']) and not re.search("5",task['opt']):
            title = task['title']
            opt = task['opt']
            btime = task['btime']
            etime = task['etime']
            chtxt = task['chtxt']
            recdb.del_reckey(recdblist.REC_ENCODE_QUE, title, chtxt, btime)
            recdb.rec_reckey(recdblist.REC_ENCODE_GRID, title, chtxt, btime, etime, opt)
            rett = "title=" + title + "," + "opt=" + opt + ";"
            break
    return rett
def main():
    port = int(configreader.getpath("gridserver_port"))
    sv = ThreadingTCPServer(('', port), Handler)
    recdblist.printutf8("This is a Rec10 GridServer.")
    recdblist.printutf8("Waiting for connections at port" + str(port))
    recdblist.printutf8('listen to:')
    print (sv.socket.getsockname())
    sv.serve_forever()

if __name__ == '__main__': main()
